@@ -291,10 +291,15 @@ int DiskList::readFSTAB()
                 if ( (disk->deviceName() != QLatin1String( "none" ))
                         && (disk->fsType() != QLatin1String( "swap" ))
                         && (disk->fsType() != QLatin1String( "sysfs" ))
+                        && (disk->fsType() != QLatin1String( "rootfs" ))
+                        && (disk->fsType() != QLatin1String( "tmpfs" ))
+                        && (disk->fsType() != QLatin1String( "debugfs" ))
+                        && (disk->fsType() != QLatin1String( "devtmpfs" ))
                         && (disk->mountPoint() != QLatin1String( "/dev/swap" ))
                         && (disk->mountPoint() != QLatin1String( "/dev/pts" ))
                         && (disk->mountPoint() != QLatin1String( "/dev/shm" ))
-                        && (!disk->mountPoint().contains(QLatin1String( "/proc" )) ) )
+                        && (!disk->mountPoint().startsWith(QLatin1String( "/sys/" )) )
+                        && (!disk->mountPoint().startsWith(QLatin1String( "/proc/" )) ) )
                 {
                     replaceDeviceEntry(disk);
                 }
@@ -442,10 +447,15 @@ void DiskList::dfDone()
                     && (disk->deviceName() != QLatin1String( "none" ))
                     && (disk->fsType() != QLatin1String( "swap" ))
                     && (disk->fsType() != QLatin1String( "sysfs" ))
+                    && (disk->fsType() != QLatin1String( "rootfs" ))
+                    && (disk->fsType() != QLatin1String( "tmpfs" ))
+                    && (disk->fsType() != QLatin1String( "debugfs" ))
+                    && (disk->fsType() != QLatin1String( "devtmpfs" ))
                     && (disk->mountPoint() != QLatin1String( "/dev/swap" ))
                     && (disk->mountPoint() != QLatin1String( "/dev/pts" ))
                     && (disk->mountPoint() != QLatin1String( "/dev/shm" ))
-                    && (!disk->mountPoint().contains(QLatin1String( "/proc" )) ) )
+                    && (!disk->mountPoint().startsWith(QLatin1String( "/sys/" )) )
+                    && (!disk->mountPoint().startsWith(QLatin1String( "/proc/" )) ) )
             {
                 disk->setMounted(true);    // it is now mounted (df lists only mounted)
                 replaceDeviceEntry(disk);
